From 665236601ab52bf85602a1d379abf728cec00fc3 Mon Sep 17 00:00:00 2001
From: Andre Sailer <andre.philippe.sailer@cern.ch>
Date: Mon, 20 Jun 2022 12:14:19 +0200
Subject: [PATCH] Geant4InputHandling: reject GEN_DOC, GEN_BEAM, GEN_OTHER
 particles

---
 DDG4/src/Geant4InputHandling.cpp | 18 +++++++++++-------
 1 file changed, 11 insertions(+), 7 deletions(-)

diff --git a/DDG4/src/Geant4InputHandling.cpp b/DDG4/src/Geant4InputHandling.cpp
index 02527d492..57448980c 100644
--- a/DDG4/src/Geant4InputHandling.cpp
+++ b/DDG4/src/Geant4InputHandling.cpp
@@ -390,14 +390,18 @@ getRelevant(set<int>& visited,
     bool rejectParticle = not p.definition()                    // completely unknown to geant4
       or (primaryConfig.m_rejectPDGs.count(abs(p->pdgID)) != 0) // quarks, gluon, "strings", W, Z etc.
       or (isProperTimeZero and p.definition()->GetPDGStable() ) // initial state electrons, etc.
-      or (isProperTimeZero and primaryConfig.m_zeroTimePDGs.count(abs(p->pdgID)) != 0 ) ; // charged 'documentation' leptons, e.g. in lepton pairs w/ FSR
+      or (isProperTimeZero and primaryConfig.m_zeroTimePDGs.count(abs(p->pdgID)) != 0 )  // charged 'documentation' leptons, e.g. in lepton pairs w/ FSR
+      or (status.isSet(G4PARTICLE_GEN_DOCUMENTATION) || status.isSet(G4PARTICLE_GEN_BEAM) || status.isSet(G4PARTICLE_GEN_OTHER))  // documentation generator status
+      or false;
+
     printout(dd4hep::DEBUG, "Input",
-	     "Checking rejection: PDG(%-*d), Definition(%s), isProperTimeZero(%s), stable(%s), reject(%s)",
-	     8, p->pdgID,
-	     p.definition() ? "true" : "false",
-	     isProperTimeZero ? "true" : "false",
-	     (bool(p.definition()) ? p.definition()->GetPDGStable() : false)  ? "true" : "false",
-	     rejectParticle ? "true" : "false");
+             "Checking rejection: PDG(%-10d), Definition(%s), isProperTimeZero(%s, %3.15f), stable(%s), doc(%s), reject(%s)",
+             p->pdgID,
+             p.definition() ? "true" : "false",
+             isProperTimeZero ? "true" : "false", proper_time,
+             (bool(p.definition()) ? p.definition()->GetPDGStable() : false)  ? "true" : "false",
+             status.isSet(G4PARTICLE_GEN_DOCUMENTATION) || status.isSet(G4PARTICLE_GEN_BEAM) || status.isSet(G4PARTICLE_GEN_OTHER) ? "true" : "false",
+             rejectParticle ? "true" : "false");
     if (not rejectParticle) {
       map<int,G4PrimaryParticle*>::iterator ip4 = prim.find(p->id);
       G4PrimaryParticle* p4 = (ip4 == prim.end()) ? 0 : (*ip4).second;
-- 
GitLab